[elephant-cvs] CVS elephant/src/db-bdb

ieslick ieslick at common-lisp.net
Sat Apr 21 17:22:39 UTC 2007


Update of /project/elephant/cvsroot/elephant/src/db-bdb
In directory clnet:/tmp/cvs-serv3920/src/db-bdb

Modified Files:
	bdb-controller.lisp package.lisp 
Log Message:
Check for cross-store loading errors in multi-store operation; more documentation; backend language to data store language

--- /project/elephant/cvsroot/elephant/src/db-bdb/package.lisp	2007/04/12 02:47:23	1.9
+++ /project/elephant/cvsroot/elephant/src/db-bdb/package.lisp	2007/04/21 17:22:37	1.10
@@ -33,7 +33,7 @@
    Elephant, but with some magic for Elephant.  In general there
    is a 1-1 mapping from functions here and functions in
    Berkeley DB, so refer to their documentation for details.")
-  (:use common-lisp uffi elephant-memutil elephant elephant-backend elephant-utils)
+  (:use common-lisp uffi elephant-memutil elephant elephant-data-store elephant-utils)
   #+cmu
   (:use alien)
   #+sbcl




More information about the Elephant-cvs mailing list
--- /project/elephant/cvsroot/elephant/src/db-bdb/bdb-controller.lisp	2007/04/12 02:47:23	1.33
+++ /project/elephant/cvsroot/elephant/src/db-bdb/bdb-controller.lisp	2007/04/21 17:22:36	1.34
@@ -43,7 +43,7 @@
 et cetera."))
 
 ;;
 ;; Backend Registry Support
 ;;
 
 (defun bdb-test-and-construct (spec)
@@ -52,7 +52,7 @@
       (error (format nil "uninterpretable spec specifier: ~A" spec))))
 
 (eval-when (:compile-toplevel :load-toplevel)
-  (register-backend-con-init :bdb 'bdb-test-and-construct))
+  (register-data-store-con-init :bdb 'bdb-test-and-construct))
 
 (defun bdb-store-spec-p (spec)
   (and (eq (first spec) :bdb)
@@ -192,7 +192,7 @@
 ;;
 ;; Store the database version
 ;;
 ;; For BDB this can be in a file; different backends may require a different approach.
 
 (defmethod database-version ((sc bdb-store-controller))
   "Elephant protocol to provide the version tag or nil if unmarked"
@@ -282,7 +282,7 @@
 (defmethod optimize-layout ((ctrl bdb-store-controller) &key start-key stop-key 
 			    (freelist-only t) (free-space nil)
 			    &allow-other-keys)
-  "Tell the backend to optimize and reclaim storage between key values"
+  "Tell the data store to optimize and reclaim storage between key values"
   (with-buffer-streams (start stop end)
     (if (null start-key)
 	(progn 
@@ -43,7 +43,7 @@
 
 ;;
-;; Backend Registry Support
+;; Data store Registry Support
 ;;
 
@@ -192,7 +192,7 @@
 ;; Store the database version
 ;;
-;; For BDB this can be in a file; different backends may require a different approach.
+;; For BDB this can be in a file; different data stores may require a different approach.
 
 (defmethod database-version ((sc bdb-store-controller))